@@ -4,7 +4,12 @@ sub Mojo::Webqq::Model::_get_friend_info{
     my $uin = shift;
     my $callback = shift;
     my $api_url = 'http://s.web2.qq.com/api/get_friend_info2';
-    my $headers = {Referer=>'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',json=>1};
+    my $headers = {
+        Referer=>'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
+        json=>1,
+        ua_request_timeout=> $self->model_update_timeout,
+        ua_retry_times => 3,
+    };
     my @query_string = (
         tuin            =>  $uin,
         vfwebqq         =>  $self->vfwebqq,
